==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/DraModelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Dra model properties.
 * @property authenticationIdentity Identity model.
 * @property customProperties Dra model custom properties.
 * @property machineId Gets or sets the machine Id where Dra is running.
 * @property machineName Gets or sets the machine name where Dra is running.
 * @property resourceAccessIdentity Identity model.
 */
public data class DraModelPropertiesArgs(
    public val authenticationIdentity: Output<IdentityModelArgs>,
    public val customProperties: Output<VMwareDraModelCustomPropertiesArgs>,
    public val machineId: Output<String>,
    public val machineName: Output<String>,
    public val resourceAccessIdentity: Output<IdentityModelArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs.builder()
            .authenticationIdentity(
                authenticationIdentity.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customProperties(customProperties.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .machineId(machineId.applyValue({ args0 -> args0 }))
            .machineName(machineName.applyValue({ args0 -> args0 }))
            .resourceAccessIdentity(
                resourceAccessIdentity.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DraModelPropertiesArgs].
 */
@PulumiTagMarker
public class DraModelPropertiesArgsBuilder internal constructor() {
    private var authenticationIdentity: Output<IdentityModelArgs>? = null

    private var customProperties: Output<VMwareDraModelCustomPropertiesArgs>? = null

    private var machineId: Output<String>? = null

    private var machineName: Output<String>? = null

    private var resourceAccessIdentity: Output<IdentityModelArgs>? = null

    /**
     * @param value Identity model.
     */
    @JvmName("inbossnolmogcrtd")
    public suspend fun authenticationIdentity(`value`: Output<IdentityModelArgs>) {
        this.authenticationIdentity = value
    }

    /**
     * @param value Dra model custom properties.
     */
    @JvmName("skeoptnpahmcoxbt")
    public suspend fun customProperties(`value`: Output<VMwareDraModelCustomPropertiesArgs>) {
        this.customProperties = value
    }

    /**
     * @param value Gets or sets the machine Id where Dra is running.
     */
    @JvmName("xncphngudiwihjid")
    public suspend fun machineId(`value`: Output<String>) {
        this.machineId = value
    }

    /**
     * @param value Gets or sets the machine name where Dra is running.
     */
    @JvmName("cbuykijwoxxmlnna")
    public suspend fun machineName(`value`: Output<String>) {
        this.machineName = value
    }

    /**
     * @param value Identity model.
     */
    @JvmName("qunhnloqnywjawwj")
    public suspend fun resourceAccessIdentity(`value`: Output<IdentityModelArgs>) {
        this.resourceAccessIdentity = value
    }

    /**
     * @param value Identity model.
     */
    @JvmName("jpkqjrrjwktluhgl")
    public suspend fun authenticationIdentity(`value`: IdentityModelArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authenticationIdentity = mapped
    }

    /**
     * @param argument Identity model.
     */
    @JvmName("scqnicdkulecpgpn")
    public suspend fun authenticationIdentity(argument: suspend IdentityModelArgsBuilder.() -> Unit) {
        val toBeMapped = IdentityModelArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.authenticationIdentity = mapped
    }

    /**
     * @param value Dra model custom properties.
     */
    @JvmName("owxolmcryjvwvuuw")
    public suspend fun customProperties(`value`: VMwareDraModelCustomPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customProperties = mapped
    }

    /**
     * @param argument Dra model custom properties.
     */
    @JvmName("oxyougriryatjwaw")
    public suspend
    fun customProperties(argument: suspend VMwareDraModelCustomPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = VMwareDraModelCustomPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.customProperties = mapped
    }

    /**
     * @param value Gets or sets the machine Id where Dra is running.
     */
    @JvmName("ffpianjyfmjkqwdv")
    public suspend fun machineId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.machineId = mapped
    }

    /**
     * @param value Gets or sets the machine name where Dra is running.
     */
    @JvmName("mcsronfqpgnmsndl")
    public suspend fun machineName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.machineName = mapped
    }

    /**
     * @param value Identity model.
     */
    @JvmName("fyrkhngscjrxvtox")
    public suspend fun resourceAccessIdentity(`value`: IdentityModelArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessIdentity = mapped
    }

    /**
     * @param argument Identity model.
     */
    @JvmName("aufjkexmuhxlhwgl")
    public suspend fun resourceAccessIdentity(argument: suspend IdentityModelArgsBuilder.() -> Unit) {
        val toBeMapped = IdentityModelArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.resourceAccessIdentity = mapped
    }

    internal fun build(): DraModelPropertiesArgs = DraModelPropertiesArgs(
        authenticationIdentity = authenticationIdentity ?: throw
            PulumiNullFieldException("authenticationIdentity"),
        customProperties = customProperties ?: throw PulumiNullFieldException("customProperties"),
        machineId = machineId ?: throw PulumiNullFieldException("machineId"),
        machineName = machineName ?: throw PulumiNullFieldException("machineName"),
        resourceAccessIdentity = resourceAccessIdentity ?: throw
            PulumiNullFieldException("resourceAccessIdentity"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/DraModelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Dra model properties.
 * @property authenticationIdentity Identity model.
 * @property customProperties Dra model custom properties.
 * @property machineId Gets or sets the machine Id where Dra is running.
 * @property machineName Gets or sets the machine name where Dra is running.
 * @property resourceAccessIdentity Identity model.
 */
public data class DraModelPropertiesArgs(
    public val authenticationIdentity: Output<IdentityModelArgs>,
    public val customProperties: Output<VMwareDraModelCustomPropertiesArgs>,
    public val machineId: Output<String>,
    public val machineName: Output<String>,
    public val resourceAccessIdentity: Output<IdentityModelArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.DraModelPropertiesArgs.builder()
            .authenticationIdentity(
                authenticationIdentity.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customProperties(customProperties.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .machineId(machineId.applyValue({ args0 -> args0 }))
            .machineName(machineName.applyValue({ args0 -> args0 }))
            .resourceAccessIdentity(
                resourceAccessIdentity.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DraModelPropertiesArgs].
 */
@PulumiTagMarker
public class DraModelPropertiesArgsBuilder internal constructor() {
    private var authenticationIdentity: Output<IdentityModelArgs>? = null

    private var customProperties: Output<VMwareDraModelCustomPropertiesArgs>? = null

    private var machineId: Output<String>? = null

    private var machineName: Output<String>? = null

    private var resourceAccessIdentity: Output<IdentityModelArgs>? = null

    /**
     * @param value Identity model.
     */
    @JvmName("yfucsjscglmylovl")
    public suspend fun authenticationIdentity(`value`: Output<IdentityModelArgs>) {
        this.authenticationIdentity = value
    }

    /**
     * @param value Dra model custom properties.
     */
    @JvmName("vkswerdjxobixgkj")
    public suspend fun customProperties(`value`: Output<VMwareDraModelCustomPropertiesArgs>) {
        this.customProperties = value
    }

    /**
     * @param value Gets or sets the machine Id where Dra is running.
     */
    @JvmName("epduhawimrfiyrrm")
    public suspend fun machineId(`value`: Output<String>) {
        this.machineId = value
    }

    /**
     * @param value Gets or sets the machine name where Dra is running.
     */
    @JvmName("osfwwdaulstvquvm")
    public suspend fun machineName(`value`: Output<String>) {
        this.machineName = value
    }

    /**
     * @param value Identity model.
     */
    @JvmName("swgntedaknprhsnn")
    public suspend fun resourceAccessIdentity(`value`: Output<IdentityModelArgs>) {
        this.resourceAccessIdentity = value
    }

    /**
     * @param value Identity model.
     */
    @JvmName("ljdqyyldokkvwahx")
    public suspend fun authenticationIdentity(`value`: IdentityModelArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authenticationIdentity = mapped
    }

    /**
     * @param argument Identity model.
     */
    @JvmName("gplbfpimjahjscdd")
    public suspend fun authenticationIdentity(argument: suspend IdentityModelArgsBuilder.() -> Unit) {
        val toBeMapped = IdentityModelArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.authenticationIdentity = mapped
    }

    /**
     * @param value Dra model custom properties.
     */
    @JvmName("qmrfaskjctxkpsbm")
    public suspend fun customProperties(`value`: VMwareDraModelCustomPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customProperties = mapped
    }

    /**
     * @param argument Dra model custom properties.
     */
    @JvmName("mnrlohcbevuygfqm")
    public suspend
    fun customProperties(argument: suspend VMwareDraModelCustomPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = VMwareDraModelCustomPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.customProperties = mapped
    }

    /**
     * @param value Gets or sets the machine Id where Dra is running.
     */
    @JvmName("pudehylsejoqxovg")
    public suspend fun machineId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.machineId = mapped
    }

    /**
     * @param value Gets or sets the machine name where Dra is running.
     */
    @JvmName("xujrihbqacndigdb")
    public suspend fun machineName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.machineName = mapped
    }

    /**
     * @param value Identity model.
     */
    @JvmName("jedkjdkbuofeutww")
    public suspend fun resourceAccessIdentity(`value`: IdentityModelArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessIdentity = mapped
    }

    /**
     * @param argument Identity model.
     */
    @JvmName("nlxfilfpsxqppcmv")
    public suspend fun resourceAccessIdentity(argument: suspend IdentityModelArgsBuilder.() -> Unit) {
        val toBeMapped = IdentityModelArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.resourceAccessIdentity = mapped
    }

    internal fun build(): DraModelPropertiesArgs = DraModelPropertiesArgs(
        authenticationIdentity = authenticationIdentity ?: throw
            PulumiNullFieldException("authenticationIdentity"),
        customProperties = customProperties ?: throw PulumiNullFieldException("customProperties"),
        machineId = machineId ?: throw PulumiNullFieldException("machineId"),
        machineName = machineName ?: throw PulumiNullFieldException("machineName"),
        resourceAccessIdentity = resourceAccessIdentity ?: throw
            PulumiNullFieldException("resourceAccessIdentity"),
    )
}
